summaryrefslogtreecommitdiffstats
path: root/kopete/protocols/groupwise/ui/gwsearch.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
commit2bc1d72869b62af05ae4feafd878203b526da8c5 (patch)
tree2676903bb600bd9646644856e354940471ad84e2 /kopete/protocols/groupwise/ui/gwsearch.h
parent937b2991d8e78166eea904c80ad04d34607017a4 (diff)
downloadtdenetwork-2bc1d72869b62af05ae4feafd878203b526da8c5.tar.gz
tdenetwork-2bc1d72869b62af05ae4feafd878203b526da8c5.zip
rename the following methods:
tqparent parent tqmask mask git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdenetwork@1246260 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kopete/protocols/groupwise/ui/gwsearch.h')
-rw-r--r--kopete/protocols/groupwise/ui/gwsearch.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/kopete/protocols/groupwise/ui/gwsearch.h b/kopete/protocols/groupwise/ui/gwsearch.h
index c3aee10a..c4e11364 100644
--- a/kopete/protocols/groupwise/ui/gwsearch.h
+++ b/kopete/protocols/groupwise/ui/gwsearch.h
@@ -36,7 +36,7 @@ Q_OBJECT
TQ_OBJECT
public:
GroupWiseContactSearch( GroupWiseAccount * account, TQListView::SelectionMode mode, bool onlineOnly,
- TQWidget *tqparent = 0, const char *name = 0);
+ TQWidget *parent = 0, const char *name = 0);
~GroupWiseContactSearch();
TQValueList< GroupWise::ContactDetails > selectedResults();
signals:
@@ -47,7 +47,7 @@ protected slots:
void slotClear();
void slotDoSearch();
void slotGotSearchResults();
// shows a GroupWiseContactProperties for the selected contact. Dialog's tqparent is this instance
void slotShowDetails();
void slotValidateSelection();
private:
@@ -47,7 +47,7 @@ protected slots:
void slotDoSearch();
void slotGotSearchResults();
- // shows a GroupWiseContactProperties for the selected contact. Dialog's tqparent is this instance
+ // shows a GroupWiseContactProperties for the selected contact. Dialog's parent is this instance
void slotShowDetails();
void slotValidateSelection();